# Rare

## A frontend for legendary, the open source Epic Games Launcher alternative

Rare is currently considered beta software and in no way feature-complete. You will probably run into issues, so it is recommend to make a backup. If you have features you want to have in this app, create an issue on github, contact me on Discord (Dummerle#7419) or build it yourself. Please report bugs so I can fix them.


### Requirements

- requests,
- pillow
- pyqt5
- notify-py
- QtAwesome

## Installation

### Installation via pip (recommend)

Execute *pip install Rare* for all users Or *pip install Rare --user* for only one user

### Windows Simple

Download Rare.exe and place it somewhere in PATH

**Note**
Using the exe-file could cause an error with the stylesheets

## Linux

- For Arch Linux is an AUR package available: [rare-git](https://aur.archlinux.org/packages/rare-git)
- Other distributions have to install it with pip or clone the repo and install it manually: *python3 setup.py install*

## Implemented

- Launch, install and uninstall games
- Authentication(Import from existing installation and via Browser)
- Download progress bar
- Settings (Legendary and games)
- Translations (English and German)

## Planned
- Sync Cloud Saves
- Offline mode
- More Translations

## Images

![alt text](https://github.com/Dummerle/Rare/blob/main/Screenshots/Rare.png?raw=true)
![alt text](https://github.com/Dummerle/Rare/blob/main/Screenshots/GameInfo.png?raw=true)
![alt text](https://github.com/Dummerle/Rare/blob/main/Screenshots/RareSettings.png?raw=true)

